User: pathoss
Date: 02/05/13 02:09:48
Modified: core/src/xdoclet Tag: MODULE_REFACTORING_BRANCH
TemplateSubTask.java
Log:
Updated javadoc.
Revision Changes Path
No revision
No revision
1.41.2.7 +23 -18 xdoclet/core/src/xdoclet/TemplateSubTask.java
Index: TemplateSubTask.java
===================================================================
RCS file: /cvsroot/xdoclet/xdoclet/core/src/xdoclet/TemplateSubTask.java,v
retrieving revision 1.41.2.6
retrieving revision 1.41.2.7
diff -u -w -r1.41.2.6 -r1.41.2.7
--- TemplateSubTask.java 13 May 2002 08:57:34 -0000 1.41.2.6
+++ TemplateSubTask.java 13 May 2002 09:09:48 -0000 1.41.2.7
@@ -26,11 +26,12 @@
import xdoclet.util.Translator;
/**
- * Generates The template file specified in templateFile configuration parameter.
It operates in two modes: per class and single output.
+ * Generates The template file specified in templateFile configuration parameter.
It operates in two modes: per class
+ * and single output.
*
* @author Ara Abrahamian ([EMAIL PROTECTED])
* @created Sep 25, 2001
- * @version $Revision: 1.41.2.6 $
+ * @version $Revision: 1.41.2.7 $
*/
public class TemplateSubTask extends SubTask
{
@@ -45,8 +46,8 @@
private boolean prefixWithPackageStructure = true;
/**
- * The destination file name. If a {0} is found it's assumed that a per class
output generation is needed, so {0} is substituted with class name; otherwise
- * a single file is generated with the specified name.
+ * The destination file name. If a {0} is found it's assumed that a per class
output generation is needed, so {0} is
+ * substituted with class name; otherwise a single file is generated with the
specified name.
*
* @see #setDestinationFile(java.lang.String)
* @see #getDestinationFile()
@@ -54,9 +55,9 @@
private String destinationFile = null;
/**
- * Applicable only to per class output generation. Specify full qualified class
name from which classes should be derived. Output generation is performed
- * only for classes of one of the types defined in this property, it's a
comma-separated list. You can control the extent in which the type search occures
- * by using 'extent' property.
+ * Applicable only to per class output generation. Specify full qualified class
name from which classes should be
+ * derived. Output generation is performed only for classes of one of the types
defined in this property, it's a
+ * comma-separated list. You can control the extent in which the type search
occures by using 'extent' property.
*
* @see #setOfType(java.lang.String)
* @see #getOfType()
@@ -66,8 +67,8 @@
private String ofType = null;
/**
- * You can control the extent in which the type search occures. Valid values
are: <i>concrete-type</i> , <i>superclass</i> and <i>hierarchy</i> which is the
- * default.
+ * You can control the extent in which the type search occures. Valid values
are: <i>concrete-type</i> , <i>
+ * superclass</i> and <i>hierarchy</i> which is the default.
*
* @see #setExtent(TemplateSubTask.ExtentTypes)
* @see #getExtent()
@@ -96,7 +97,8 @@
private GenerationManager generationManager;
/**
- * Converts the full qualified class name to a valid path with File.separator
characters instead of . characters and class name postfixed by a ".java".
+ * Converts the full qualified class name to a valid path with File.separator
characters instead of . characters and
+ * class name postfixed by a ".java".
*
* @param className Description of Parameter
* @return Description of the Returned Value
@@ -127,7 +129,8 @@
}
/**
- * By default supports, but some subtasks may not support because global
packageSubstitution is for public interfaces/classes, not good for impl classes.
+ * By default supports, but some subtasks may not support because global
packageSubstitution is for public
+ * interfaces/classes, not good for impl classes.
*
* @return true
*/
@@ -307,7 +310,8 @@
}
/**
- * This method should be called to set a template file programmatically. The
URL is typically obtained with a getClass().getResource( templateName )
+ * This method should be called to set a template file programmatically. The
URL is typically obtained with a
+ * getClass().getResource( templateName )
*
* @param templateFile the URL of the template file
*/
@@ -317,7 +321,8 @@
}
/**
- * This method is called from Ant in <template templateFile="blabla"/> Don't
call this explicitly, use the URL method instead.
+ * This method is called from Ant in <template templateFile="blabla"/> Don't
call this explicitly, use the URL
+ * method instead.
*
* @param templateFile the file name (real file!) of the template
*/
@@ -583,8 +588,8 @@
}
/**
- * Returns true if output not already generated for clazz, and is of the
specified type and has the specified class tag; false otherwise. If returned false,
- * no output file is generated for clazz.
+ * Returns true if output not already generated for clazz, and is of the
specified type and has the specified class
+ * tag; false otherwise. If returned false, no output file is generated for
clazz.
*
* @param clazz Description of Parameter
* @return Description of the Returned Value
@@ -702,14 +707,14 @@
* Describe what the method does
*
* @param templateURL Describe what the parameter does
* @param output_file Describe what the parameter does
* @exception TemplateException Describe the exception
*/
- protected void startEngine(URL templateURL, File output_file) throws
TemplateException
+ protected void startEngine(URL templateURL, File outputFile) throws
TemplateException
{
engineStarted();
- getEngine().setOutput(output_file);
+ getEngine().setOutput(outputFile);
getEngine().setTemplateURL(templateURL);
getEngine().start();
_______________________________________________________________
@@ -702,14 +707,14 @@
*
* @param templateURL Describe what the parameter does
- * @param output_file Describe what the parameter does
+ * @param outputFile Describe what the parameter does
* @exception TemplateException Describe the exception
*/
Have big pipes? SourceForge.net is looking for download mirrors. We supply
the hardware. You get the recognition. Email Us: [EMAIL PROTECTED]
_______________________________________________
Xdoclet-devel mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/xdoclet-devel